@@ -5,4 +5,4 @@ LIVE_IMAGE_URL = "https://www.sky.de{0}"
 PVR_IMAGE_URL = "https://www.sky.de{0}"
 CHANNEL_IMAGE_URL = "https://www.sky.de{0}"
 TIMEZONE = "Europe/Berlin"
-CHANNEL_URL = "https://raw.githubusercontent.com/RogerSelwyn/skyq_remote/master/pyskyqremote/country/channels-de.json"
+CHANNEL_URL = "https://raw.githubusercontent.com/RogerSelwyn/skyq_remote/master/pyskyqremote/country/channels-de.json"  # pylint: disable=line-too-long
